@@ -4,17 +4,15 @@
 from la.deflarry import larry
 
 try:
-    from la.io import (IO, save, load, repack, is_archived_larry,
-                       archive_directory)
+    from la.io import IO
+    from la.io import *
 except:
     # Cannot import h5py; no archiving available.
     pass        
 
 from numpy import nan, inf
 
-from la.flarry import (union, intersection, stack, panel, cov, rand, randn,
-                       align, align_raw, binaryop, add, subtract, multiply,
-                       divide, unique)
+from la.flarry import * 
 from la.util.report import info
 from la.version import __version__
 from la.util import testing
