@@ -7,6 +7,11 @@ from la.flabel import flattenlabel, listmap, listmap_fill
 from la.farray import covMissing
 from la.missing import missing_marker, ismissing
 
+__all__ = ['align', 'align_axis', 'align_raw', 'lrange', 'empty', 'ones',
+           'zeros', 'isaligned', 'union', 'intersection', 'binaryop', 'add',
+           'sortby', 'subtract', 'multiply', 'divide', 'unique', 'stack',
+           'panel', 'cov', 'rand', 'randn']
+
 
 # Alignment -----------------------------------------------------------------
 
@@ -22,13 +27,14 @@ def align(lar1, lar2, join='inner', cast=True):
     lar2 : larry
         One of the input larrys. Must have the same number of dimensions as
         `lar1`.
-    join : {'inner', 'outer', 'left', 'right', list}, optional
+    join : {'inner', 'outer', 'left', 'right', 'skip', list}, optional
         The join method used to align the two larrys. The default join method
         along each axis is 'inner', i.e., the intersection of the labels. If
         `join` is a list of strings then the length of the list should be the 
         same as the number of dimensions of the two larrys. The first element
         in the list is the join method for axis=0, the second element is the
-        join method for axis=1, and so on.
+        join method for axis=1, and so on. The 'skip' join method means to
+        not align the specified axis.
     cast : bool, optional
         Only float, str, and object dtypes have missing value markers (la.nan,
         '', and None, respectively). Other dtypes, such as int and bool, do
@@ -45,6 +51,11 @@ def align(lar1, lar2, join='inner', cast=True):
         A copy of the aligned version of `lar1`.
     lar4 : larry
         A copy of the aligned version of `lar2`.                     
+    
+    See Also
+    --------
+    la.isaligned: Return True if two larrys are aligned along specified axis.
+    la.align_raw: Low level version of la.align.
         
     Examples
     --------
@@ -89,15 +100,33 @@ def align(lar1, lar2, join='inner', cast=True):
     array([1, 2, 3])                              
 
     """
+    
+    # Align
     x1, x2, label, x1isview, x2isview = align_raw(lar1, lar2, join=join,
                                                    cast=cast)
+    
+    # Convert x1 array to larry
+    label1 = []
+    for j, lab in enumerate(label):
+        if lab is None:
+            label1.append(list(lar1.label[j]))
+        else:
+            label1.append(list(lab))
     if x1isview:    
         x1 = x1.copy()
-    lar3 = larry(x1, label, integrity=False)        
-    label = [list(lab) for lab in label]
+    lar3 = larry(x1, label1, validate=False)
+
+    # Convert x2 array to larry
+    label2 = []
+    for j, lab in enumerate(label):
+        if lab is None:
+            label2.append(list(lar2.label[j]))
+        else:
+            label2.append(list(lab))
     if x2isview:    
         x2 = x2.copy()
-    lar4 = larry(x2, label, integrity=False)    
+    lar4 = larry(x2, label2, validate=False)
+
     return lar3, lar4
 
 def align_raw(lar1, lar2, join='inner', cast=True):    
@@ -117,13 +146,14 @@ def align_raw(lar1, lar2, join='inner', cast=True):
     lar2 : larry
         One of the input larrys. Must have the same number of dimensions as
         `lar1`.
-    join : {'inner', 'outer', 'left', 'right', list}, optional
+    join : {'inner', 'outer', 'left', 'right', 'skip', list}, optional
         The join method used to align the two larrys. The default join method
         along each axis is 'inner', i.e., the intersection of the labels. If
         `join` is a list of strings then the length of the list should be the 
         same as the number of dimensions of the two larrys. The first element
         in the list is the join method for axis=0, the second element is the
-        join method for axis=1, and so on.
+        join method for axis=1, and so on. The 'skip' join method means to
+        not align the specified axis.
     cast : bool, optional
         Only float, str, and object dtypes have missing value markers (la.nan,
         '', and None, respectively). Other dtypes, such as int and bool, do
@@ -141,7 +171,8 @@ def align_raw(lar1, lar2, join='inner', cast=True):
     x2 : ndarray
         The aligned version of `lar2`.
     label : list of lists
-        The label of the joined larrys.
+        The label of the joined larrys. If join method along any axis is
+        'skip', then the corresponding entry of label is `None`.
     x1isview : bool
         True if x1 is a view of lar1.x; False otherwise. A view of lar1.x is
         retuned if the labels of `lar1` and `lar2` are the same along all
@@ -153,7 +184,8 @@ def align_raw(lar1, lar2, join='inner', cast=True):
         
     See Also
     --------
-    la.align: Align two larrys using one of five join methods.   
+    la.align: Align two larrys using one of five join methods.
+    la.isaligned: Return True if two larrys are aligned along specified axis.
         
     Notes
     -----
@@ -335,13 +367,207 @@ def align_raw(lar1, lar2, join='inner', cast=True):
                     index1 = [slice(None)] * ndim
                     index1[ax] = idx1_miss                            
                     x1[index1] = miss1 
-                x1isview = False                                 
+                x1isview = False
+        elif joinax == 'skip':
+            list3 = None
         else:
             raise ValueError, 'join type not recognized'  
         label.append(list3)
     
     return x1, x2, label, x1isview, x2isview
+
+def align_axis(lars, axis=0, join='inner', flag=False):
+    """
+    Align many larrys along potentially different axes.
+
+    Parameters
+    ----------
+    lars : array_like
+        A collection (list, tuple, set, array, etc.) of larrys to align.
+    axis : {int, array_like}, optional
+        An integer indicating which axis along which to align the larrys in
+        `lars`, or a sequence of integers of the same length as `lars`
+        indicating which axis to use for each entry in `lars`.
+    join : {'inner', 'outer', 'left', 'right'}, optional
+        If 'inner', then labels present in every larry will be kept. If
+        'outer', all labels appearing in any array are kept, and additional
+        entries are added to larrys containing fewer labels. See la.morph() for
+        rules on how this is done. If 'right' or 'left' then the labels of the
+        output will match those of either the first or last entry of `lars`,
+        respectively
+
+    Returns
+    -------
+    (lar1, lar2, ...) : tuple
+        Tuple of larrys, one corresponding to each entry of lars. None of the
+        output refer to input, and the labels of the output do not refer to one
+        another.
+
+    Examples
+    --------
+
+    Create three larrys:
+
+    >>> l1 = la.larry([1, 2, 3, 4], [['a', 'b', 'c', 'd']])
+    >>> l2 = la.larry([[4, 5], [6, 7]], [['x', 'y'], ['c', 'd']])
+    >>> l3 = la.larry([8, 9, 10], [['c', 'd', 'e']])
     
+    Align the first axis of the first larry with the second axis of the
+    second larry using an inner join:
+
+    >>> a1, a2 = la.align_axis([l1, l2], axis=[0, 1])
+    >>> a1
+    label_0
+        c
+        d
+    x
+    array([3, 4])
+    >>> a2
+    label_0
+        x
+        y
+    label_1
+        c
+        d
+    x
+    array([[4, 5],
+           [6, 7]])
+    
+    Align the first axis of two larrys with an outer join:
+
+    >>> a1, a2 = la.align_axis([l1, l3], join='outer')
+    >>> a1
+    label_0
+        a
+        b
+        c
+        d
+        e
+    x
+    array([  1.,   2.,   3.,   4.,  nan])
+    >>> a2
+    label_0
+        a
+        b
+        c
+        d
+        e
+    x
+    array([ nan,  nan,   8.,   9.,  10.])
+
+    Align multiple larrys with an inner join:
+
+    >>> a1, a2, a3 = la.align_axis([l1, l2, l3], axis=[0, 1, 0])
+    >>> a1
+    label_0
+        c
+        d
+    x
+    array([3, 4])
+    >>> a2
+    label_0
+        x
+        y
+    label_1
+        c
+        d
+    x
+    array([[4, 5],
+           [6, 7]])
+    >>> a3
+    label_0
+        c
+        d
+    x
+    array([8, 9])
+
+    """
+
+    # Input checks and preprocessing
+    nlar = len(lars)
+    if isinstance(axis, int):
+        axis = [axis for j in range(nlar)]
+    for j, lar in enumerate(lars):
+        if not isinstance(lar, larry):
+            raise ValueError("Inputs must be larry.")
+        if (axis[j] >= lar.ndim) or (axis[j] < -lar.ndim):
+            raise ValueError("Axis out of range for input larry %d" % j)
+    if join not in ['inner', 'outer', 'left', 'right']:
+        raise ValueError("Value of `join` not recognized.")
+
+    # Alignment
+    if join == 'left':
+        label = lars[0].label[axis[0]]
+    elif join == 'right':
+        label = lars[-1].label[axis[-1]]
+    else:
+        labels = [set(lar.label[axis[j]]) for j, lar in enumerate(lars)]
+        label = labels[0]
+        if join == 'inner': 
+            for new_label in labels[1:]:
+                label &= new_label
+        elif join == 'outer':
+            for new_label in labels[1:]:
+                label |= new_label
+        label = list(label)
+        label.sort() 
+    lars_out = []
+
+    # Create output
+    for j, lar in enumerate(lars):
+        lab = list(label)
+        lars_out.append(lar.morph(lab, axis[j]))
+
+    return tuple(lars_out)
+
+def isaligned(lar1, lar2, axis=None):
+    """
+    Return True if labels of two given larrys are aligned along specified axis.
+
+    Parameters
+    ----------
+    lar1 : larry
+        Input.
+    lar2 : larry
+        Input
+    axis : {int, None}, optional
+        The axis along which to check for aligment of labels. By default
+        (axis=None) all axes are checked.
+
+    Returns
+    -------
+    y : bool
+        Returns True if labels are aligned; False if labels are not aligned.
+    
+    See Also
+    --------
+    la.align: Align two larrys using one of five join methods.   
+
+    Examples
+    --------
+    Make two 2d larrys that are aligned along columns but not rows:
+
+    >>> lar1 = larry([[1, 2], [3, 4]], [['row1', 'row2'], ['col1', 'col2']])
+    >>> lar2 = larry([[1, 2], [3, 4]], [['row2', 'row1'], ['col1', 'col2']])
+
+    The two larrys are not aligned:
+
+    >>> la.isaligned(lar1, lar2)
+    False
+    >>> la.isaligned(lar1, lar2, axis=0)
+    False
+
+    But the columns of the two larrys are aligned:
+
+    >>> la.isaligned(lar1, lar2, axis=1)
+    True
+    
+    """
+    if axis is None:
+        return lar1.label == lar2.label
+    else:
+        return lar1.label[axis] == lar2.label[axis]
+
 def union(axis, *args):
     """
     Union of labels along specified axis.
@@ -547,20 +773,20 @@ def binaryop(func, lar1, lar2, join='inner', cast=True, missone='ignore',
     if missone != 'ignore':    
         missone1 = miss1 & ~miss2
         if missone1.any():
-            x1[missone1] = missone
+            np.putmask(x1, missone1, missone)
         missone2 = miss2 & ~miss1    
         if missone2.any():
-            x2[missone2] = missone
+            np.putmask(x2, missone2, missone)
     if misstwo != 'ignore':            
         misstwo12 = miss1 & miss2    
         if misstwo12.any():
-            x1[misstwo12] = misstwo
-            x2[misstwo12] = misstwo           
+            np.putmask(x1, misstwo12, misstwo)
+            np.putmask(x2, misstwo12, misstwo)
             
     # Binary function
     x = func(x1, x2, **kwargs)
     
-    return larry(x, label, integrity=False)
+    return larry(x, label, validate=False)
     
 def add(lar1, lar2, join='inner', cast=True, missone='ignore',
         misstwo='ignore'):
@@ -1201,65 +1427,45 @@ def panel(lar):
     Examples
     --------
     First make a 3d larry:
-    
-    >>> import numpy as np
-    >>> y = larry(np.arange(24).reshape(2,3,4))
-    >>> y
+
+    >>> x = np.ones((2,2)).cumsum(0) - 1
+    >>> lar = la.larry(x, [['r1', 'r2'], ['c1', 'c2']])
+    >>> lar = lar.insertaxis(0, "name")
+    >>> lar 
     label_0
-        0
-        1
+        name
     label_1
-        0
-        1
-        2
+        r1
+        r2
     label_2
-        0
-        1
-        2
-        3
+        c1
+        c2
     x
-    array([[[ 0,  1,  2,  3],
-            [ 4,  5,  6,  7],
-            [ 8,  9, 10, 11]],
-    .
-           [[12, 13, 14, 15],
-            [16, 17, 18, 19],
-            [20, 21, 22, 23]]])
-            
-    Then make a panel:        
-            
-    >>> la.func.panel(y)
+    array([[[ 0.,  0.],
+            [ 1.,  1.]]])
+
+    Then make a panel:
+
+    >>> la.panel(lar) 
     label_0
-        (0, 0)
-        (0, 1)
-        (0, 2)
-        ...
-        (2, 1)
-        (2, 2)
-        (2, 3)
+        ('r1', 'c1')
+        ('r1', 'c2')
+        ('r2', 'c1')
+        ('r2', 'c2')
     label_1
-        0
-        1
+        name
     x
-    array([[ 0, 12],
-           [ 4, 16],
-           [ 8, 20],
-           [ 1, 13],
-           [ 5, 17],
-           [ 9, 21],
-           [ 2, 14],
-           [ 6, 18],
-           [10, 22],
-           [ 3, 15],
-           [ 7, 19],
-           [11, 23]])            
-    
+    array([[ 0.],
+           [ 0.],
+           [ 1.],
+           [ 1.]])
+ 
     """
     if lar.ndim != 3:
         raise ValueError, "lar must be 3d."
     y = lar.copy()
     y.label = [flattenlabel([y.label[1], y.label[2]])[0], y.label[0]]
-    y.x = y.x.T.reshape(-1, y.shape[0])
+    y.x = y.x.T.reshape(-1, y.shape[0], order="F")
     return y
 
 def cov(lar):
@@ -1291,10 +1497,9 @@ def cov(lar):
     """
     if lar.ndim != 2:
         raise ValueError, 'This function only works on 2d larrys'      
-    y = lar.copy()
-    y.label[1] = list(y.label[0])
-    y.x = covMissing(y.x)
-    return y
+    label = [list(lar.label[0]), list(lar.label[0])]
+    x = covMissing(lar.x)
+    return larry(x, label, validate=False)
 
 # Random -----------------------------------------------------------    
     
@@ -1311,7 +1516,7 @@ def rand(*args, **kwargs):
         may be omitted if you pass in a label as a keyword argument.
     kwargs : keyword arguments, optional
         Keyword arguments to use in the construction of the larry such as
-        label and integrity. If a label is passed then its dimensions must
+        label and validate. If a label is passed then its dimensions must
         match the `n` integers passed in or, optionally, you can pass in the
         label without the `n` shape integers. If rand is passed in then that
         will be used to generate the random numbers. In that way you can set
@@ -1409,7 +1614,7 @@ def randn(*args, **kwargs):
         may be omitted if you pass in a label as a keyword argument.
     kwargs : keyword arguments, optional
         Keyword arguments to use in the construction of the larry such as
-        label and integrity. If a label is passed then its dimensions must
+        label and validate. If a label is passed then its dimensions must
         match the `n` integers passed in or, optionally, you can pass in the
         label without the `n` shape integers. If randn is passed in then that
         will be used to generate the random numbers. In that way you can set
@@ -1492,4 +1697,392 @@ def randn(*args, **kwargs):
         return randnfunc()         
     else:
         raise ValueError, 'Input parameters not recognized'
-                            
+ 
+def sortby(lar, element, axis, reverse=False):
+    """
+    Sort 2d larry by the row or column corresponding to given label element.
+    
+    Parameters
+    ----------
+    lar : larry 
+        A 2d input larry to be sorted.
+    element : str
+        The label element specifying the row or column by which to sort.
+    axis : int
+        The axis along which the element is located. Sorting takes place along
+        the opposite axis.
+    reverse : bool, optional
+        Keyword indicating whether to sort in ascending order (False) or
+        descending order (True). The default is to sort in ascending order.
+    
+    Returns
+    -------
+    lar2 : larry
+        A sorted copy of the larry.
+    
+    Examples
+    --------
+    Create a larry:
+
+    >>> label = [['a','b'], ['c','d','e']]
+    >>> x = np.array([[1, 2, 3], [3, 1, 2]])
+    >>> lar = la.larry(x, label)
+
+    Sort larry by row 'b' along the first axis:
+
+    >>> la.sortby(lar, 'b', axis=0)
+    label_0
+        a
+        b
+    label_1
+        d
+        e
+        c
+    x
+    array([[2, 3, 1],
+           [1, 2, 3]])
+
+    """
+    if lar.ndim != 2:
+        raise ValueError("`lar` must be 2d.")
+    if lar.size == 0:
+        if element in lar.label[axis]:
+            return lar.copy()
+    if axis < 0:
+        axis += lar.ndim
+    if axis not in (0, 1):
+        raise ValueError("`axis` must be 0 or 1.")
+    idx = lar.labelindex(element, axis)
+    if axis == 0:
+        idx = lar.x[idx,:].argsort()
+        if reverse:
+            idx = idx[::-1]
+        return lar[:,idx]
+    else:
+        idx = lar.x[:,idx].argsort()
+        if reverse:
+            idx = idx[::-1]
+        return lar[idx,:]
+
+# Instantiation shortcuts---------------------------------------------------
+
+def lrange(shape=None, label=None, start=0, step=1, dtype=None):
+    """
+    Return a new larry of sequential integers, shaped according to input.
+
+    Parameters
+    ----------
+    shape : {int, tuple}, optional
+        If `shape` is not given, then `label` must be supplied. If `shape` is
+        an int, output will be one-dimensional.
+    label : list, optional
+        List of lists, a label for the larry produced.
+    start : int, optional
+        First integer appearing. Defaults to 0
+    step : int, optional
+        Difference between successive integers. Defaults to 1.
+    dtype : data-type, optional
+        The desired data-type for the array, e.g., `numpy.int8`.  Default is
+        `numpy.float64`.
+
+    Returns
+    -------
+    lar : larry
+        a ``(d1, ..., dn)``-shaped larry of consecutive integers (or spaced
+        `step` apart if such a keyword argument is used), labeled either by
+        integers or by the labels supplied.
+  
+    See Also
+    --------
+    empty, ones, zeros
+  
+    Examples
+    --------
+    A basic, 1d lrange using the 'dtype' argument:
+    
+    >>> la.lrange(3, dtype='f4') 
+    label_0
+        0
+        1
+        2
+    x
+    array([0.0, 1.0, 2.0], dtype=np.float32)
+ 
+    A multi-dimensional lrange:
+
+    >>> la.lrange((2,3,3))
+    label_0
+        0
+        1
+    label_1
+        0
+        1
+        2
+    label_2
+        0
+        1
+        2
+    x
+    array([[[ 0,  1,  2],
+            [ 3,  4,  5],
+            [ 6,  7,  8]],
+    .
+           [[ 9, 10, 11],
+            [12, 13, 14],
+            [15, 16, 17]]])
+    
+    Using the `label` keyword:
+
+    >>> la.lrange(label=[['a', 'b']])
+    label_0
+        a
+        b
+    x
+    array([0, 1])
+    
+    """
+    if label is not None:
+        shape = [len(lab) for lab in label]
+    else:
+        if shape is None:
+           raise ValueError("Either `label` or `shape` must be supplied.")
+    total = np.product(shape)
+    data = np.arange(start=start, stop=step*total+start, step=step,
+                     dtype=dtype).reshape(shape)
+    return larry(data, label)
+
+def empty(shape=None, label=None, dtype=None, order='C'):
+    """
+    Return a new larry of given shape and type, without initializing entries.
+    
+    Parameters
+    ----------
+    shape : {int, tuple}, optional
+        If `shape` is not given, then `label` must be supplied. If `shape` is
+        an int, output will be one-dimensional.
+    label : list, optional
+        List of lists, a label for the larry produced. 
+    dtype : data-type, optional
+        The desired data-type for the array, e.g., `numpy.int8`.  Default is
+        `numpy.float64`.
+    order : {'C', 'F'}, optional
+        Whether to store multidimensional data in C- or Fortran-contiguous
+        (row- or column-wise) order in memory. The default is C order.
+
+    Returns
+    -------
+    lar : larry
+        a ``(d1, ..., dn)``-shaped larry of uninitialized values, labeled either
+        by integers or by the labels supplied.
+    
+    See Also
+    --------
+    zeros, ones, lrange
+    
+    Examples
+    --------
+    A basic, 1d larry using the 'dtype' argument:
+    
+    >>> la.empty(3, dtype='i4') 
+    label_0
+        0
+        1
+        2
+        3
+        4
+    x
+    array([0, -7, 987], dtype=np.int32)
+ 
+    A multi-dimensional larry:
+    
+    >>> la.empty(2, 3, 3)
+    label_0
+        0
+        1
+    label_1
+        0
+        1
+        2
+    label_2
+        0
+        1
+        2
+    x
+    array([[[      0e0,  0e0,  0e0],
+            [      0e0,  0e0,  0e0],
+            [      0e0,  0e0,  0e0]],
+           [[ 3.2e-254,  0e0,  0e0],
+            [     0e0.,  0e0,  0e0],
+            [     0e0,   0e0,  0e0]]])
+    
+    Using the 'label' argument:
+
+    >>> la.empty(label=[['a', 'b']])
+    label_0
+        a
+        b
+    x
+    array([0e0, -3.2e-256])
+    
+    """
+    if label is not None:
+        shape = [len(lab) for lab in label]
+    else:
+        if shape is None:
+           raise ValueError("Either `label` or `shape` must be supplied.")
+    data = np.empty(shape, dtype, order)
+    return larry(data, label)
+
+def ones(shape=None, label=None, dtype=None, order='C'):
+    """
+    Return a new larry of given shape and type, filled with ones.
+    
+    Parameters
+    ----------
+    shape : {int, tuple}, optional
+        If `shape` is not given, then `label` must be supplied. If `shape` is
+        an int, output will be one-dimensional.
+    label : list, optional
+        List of lists, a label for the larry produced.
+    dtype : data-type, optional
+        The desired data-type for the array, e.g., `numpy.int8`.  Default is
+        `numpy.float64`.
+    order : {'C', 'F'}, optional
+        Whether to store multidimensional data in C- or Fortran-contiguous
+        (row- or column-wise) order in memory. The default is C order.
+
+    Returns
+    -------
+    lar : larry
+        a ``(d1, ..., dn)``-shaped larry of ones, labeled either by
+        integers or by the labels supplied.
+    
+    See Also
+    --------
+    empty, zeros, lrange
+    
+    Examples
+    --------
+    A basic, 1d larry using the 'dtype' argument:
+    
+    >>> la.ones(3, dtype='i4') 
+    label_0
+        0
+        1
+        2
+    x
+    array([1, 1, 1], dtype=np.int32)
+ 
+    A multi-dimensional larry:
+
+    >>> la.ones(2, 3, 3)
+    label_0
+        0
+        1
+    label_1
+        0
+        1
+        2
+    label_2
+        0
+        1
+        2
+    x
+    array([[[ 1.,  1.,  1.],
+            [ 1.,  1.,  1.],
+            [ 1.,  1.,  1.]],
+    .
+           [[ 1.,  1.,  1.],
+            [ 1.,  1.,  1.],
+            [ 1.,  1.,  1.]]])
+    
+    Using the 'label' argument:
+
+    >>> la.ones(label=[['a', 'b']])
+    label_0
+        a
+        b
+    x
+    array([1., 1.])
+    
+    """
+    lar = empty(shape, label, dtype, order)
+    lar.x.fill(1)
+    return lar
+
+def zeros(shape=None, label=None, dtype=None, order='C'):
+    """
+    Return a new larry of given shape and type, filled with zeros.
+    
+    Parameters 
+    ----------
+    shape : {int, tuple}, optional
+        If `shape` is not given, then `label` must be supplied. If `shape` is
+        an int, output will be one-dimensional.
+    label : list, optional
+        List of lists, a label for the larry produced.
+    dtype : data-type, optional
+        The desired data-type for the array, e.g., `numpy.int8`.  Default is
+        `numpy.float64`.
+    order : {'C', 'F'}, optional
+        Whether to store multidimensional data in C- or Fortran-contiguous
+        (row- or column-wise) order in memory.
+
+    Returns
+    -------
+    lar : larry
+        a ``(d1, ..., dn)``-shaped larry of zeros, labeled either by
+        integers or by the labels supplied.
+    
+    See Also
+    --------
+    empty, ones, lrange
+
+    Examples
+    --------
+    A basic, 1d larry using the 'dtype' argument:
+    
+    >>> la.zeros(3, dtype='i4') 
+    label_0
+        0
+        1
+        2
+    x
+    array([0, 0, 0], dtype=np.int32)
+ 
+    A multi-dimensional larry:
+
+    >>> la.zeros(2, 3, 3)
+    label_0
+        0
+        1
+    label_1
+        0
+        1
+        2
+    label_2
+        0
+        1
+        2
+    x
+    array([[[ 0.,  0.,  0.],
+            [ 0.,  0.,  0.],
+            [ 0.,  0.,  0.]],
+    .
+           [[ 0.,  0.,  0.],
+            [ 0.,  0.,  0.],
+            [ 0.,  0.,  0.]]])
+    
+    Using the 'label' argument:
+
+    >>> la.zeros(label=[['a', 'b']])
+    label_0
+        a
+        b
+    x
+    array([0., 0.])
+    
+    """
+    lar = empty(shape, label, dtype, order)
+    lar.x.fill(0)
+    return lar
