@@ -10,7 +10,10 @@ from la.util.misc import randstring
 
 from la import larry
 
-        
+__all__ = ['IO', 'save', 'load', 'repack', 'is_archived_larry',
+           'archive_directory']
+       
+
 class IO(object):
     "Save and load larrys in HDF5 format using a dictionary-like interface."
     
@@ -359,9 +362,17 @@ def save(file, lar, key):
     
     If all labels along an axis are dates of type datetime.date, then the
     dates are converted to integers before saving and the HDF5 Dataset used
-    to store that label is assigned an attribute name 'isdate' which is set
-    to True. When loading the larry, the dates will automatically be converted
-    back to datetime.date dates.
+    to store that label is assigned an attribute name 'datetime_type' which is set
+    to 'date'. When loading the larry, the dates will automatically be
+    converted back to datetime.date dates.
+    
+    Similarly, if the labels are of type datetime.time, then we convert to
+    integers and set the attribute to 'date' when saving and automatically
+    convert back to datetime.time when loading.
+
+    Finally, if the labels are datetime.datetime then the attribute is set
+    to 'datetime' and the labels are converted to tuples when saving and
+    back to datetime.datetime when loading.
     
     Parameters
     ----------
@@ -406,8 +417,8 @@ def save(file, lar, key):
     fkey.attrs['larry'] = True
     fkey['x'] = lar.x
     for i in range(lar.ndim):
-        fkey[str(i)], isdate = _list2array(lar.label[i])
-        fkey[str(i)].attrs['isdate'] = isdate
+        fkey[str(i)], datetime_type = _list2array(lar.label[i])
+        fkey[str(i)].attrs['datetime_type'] = datetime_type
     
     # Close if file is a filename   
     if opened:
@@ -600,8 +611,13 @@ def _load_label(group, ndim):
     label = []
     for i in range(ndim):
         labellist = group[str(i)][:].tolist()
-        if group[str(i)].attrs['isdate']:
+        datetime_type = group[str(i)].attrs['datetime_type']
+        if datetime_type == 'date':
             labellist = map(datetime.date.fromordinal, labellist)
+        elif datetime_type == 'time':
+            labellist = map(tuple2time, labellist)
+        elif datetime_type == 'datetime':
+            labellist = map(tuple2datetime, labellist)
         label.append(labellist)
     return label                     
 
@@ -614,11 +630,20 @@ def _list2array(x):
         msg = 'Elements of a label along any one dimension must be of the '
         msg += 'same type.'  
         raise TypeError, msg
-    isdate = False    
+    datetime_type = 'not_datetime'
+    dtype = None
     if type0 == datetime.date:
         x = map(datetime.date.toordinal, x)
-        isdate = True    
-    return np.asarray(x), isdate                 
+        datetime_type = 'date'
+    elif type0 == datetime.time:
+        x = map(time2tuple, x)
+        datetime_type = 'time'
+        dtype = "i4,i4,i4,i4"
+    elif type0 == datetime.datetime:
+        x = map(datetime2tuple, x)
+        datetime_type = 'datetime'
+        dtype = ','.join(["i4" for i in range(len(x[0]))])
+    return np.asarray(x, dtype=dtype), datetime_type
     
 def _openfile(file):
     """
@@ -652,7 +677,7 @@ def _is_archived_larry(obj):
     "True if obj is an archived larry, False otherwise."
     if isinstance(obj, h5py.Group):
         if 'larry' in obj.attrs:
-            if obj.attrs['larry'] is True:
+            if obj.attrs['larry'] == True:
                 if 'x' in obj:
                     ndim = len(obj['x'].shape)
                     labels = map(str, range(ndim))
@@ -672,4 +697,21 @@ def _create_nested_groups(f, path):
             if not isinstance(f[group], h5py.Group):
                 msg = '%s already exists and is not a h5.py.Group object.'
                 raise ValueError, msg % group   
-                    
+                   
+def datetime2tuple(dt):
+    "Convert datetime.datetime to tuple; tzinfo, if any, is lost."
+    return (dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second,
+            dt.microsecond)
+
+def tuple2datetime(i):
+    "Convert tuple to a datetime.datetime object."
+    return datetime.datetime(*i)    
+
+def time2tuple(t):
+    "Convert datetime.time to tuple; tzinfo, if any, is lost."
+    return (t.hour, t.minute, t.second, t.microsecond)
+
+def tuple2time(i):
+    "Convert tuple to a datetime.time object."
+    return datetime.time(*i)
+    
