@@ -1,5 +1,9 @@
 "Test larry methods for proper handling of all NaN input"
 
+# For support of python 2.5
+from __future__ import with_statement
+
+import numpy as np
 from numpy.testing import assert_equal
 
 from la import larry, nan
@@ -14,7 +18,7 @@ def functions():
               'median', 'std', 'var', 'min', 'max', 'demean', 'demedian',
               'zscore', 'geometric_mean'],
          (0,): ['cumsum', 'cumprod', 'ranking', 'lastrank'],
-         (1,): ['power', 'movingsum', 'movingsum_forward'],
+         (1,): ['power', 'move_sum', 'movingsum_forward'],
          (2,): ['movingrank', 'quantile']} 
     return f                   
                         
@@ -23,12 +27,11 @@ def test_all_nan():
     err_msg = "%s did not return NaN"
     for parameters, methods in functions().iteritems():
         for method in methods:
-            actual = getattr(lar(), method)(*parameters)                    
+            with np.errstate(invalid='ignore', divide='ignore'):
+                actual = getattr(lar(), method)(*parameters)                    
             if type(actual) == larry:
                 desired = lar()
                 yield assert_larry_equal, actual, desired, err_msg % method
             else:  
                 desired = nan  
                 yield assert_equal, actual, desired, err_msg % method
-             
-
