@@ -1,8 +1,11 @@
 
-import unittest
+# For support of python 2.5
+from __future__ import with_statement
+
 import os
 import tempfile
 from copy import deepcopy
+from StringIO import StringIO
 
 import numpy as np
 nan = np.nan
@@ -97,7 +100,8 @@ def test_methods_reduce():
         for opname in meth_reduce1:
             if np.isnan(la.x).any(): 
                 npmaop = getattr(np.ma,opname)
-                npop = lambda *args: np.ma.filled(npmaop(np.ma.fix_invalid(args[0]),args[1]),np.nan)
+                npop = lambda *args: np.ma.filled(npmaop(np.ma.fix_invalid(
+                       args[0]),args[1]),np.nan)
             else:
                 npop = getattr(np,opname)
                 
@@ -106,7 +110,8 @@ def test_methods_reduce():
                 p = getattr(la, opname)(axis)
                 tlab = deepcopy(la.label)
                 tlab.pop(axis)                
-                yield assert_larry, opname, p, t, tlab, laname+' axis='+str(axis)
+                yield assert_larry, opname, p, t, tlab, \
+                      laname+' axis='+str(axis)
 
 def test_methods_nonan():
     "larry nonan nose test"
@@ -119,7 +124,8 @@ def test_methods_nonan():
                 t = npop(la.x, axis) 
                 p = getattr(la, opname)(axis)
                 tlab = deepcopy(la.label)
-                yield assert_larry, opname, p, t, tlab, laname+' axis='+str(axis)
+                yield assert_larry, opname, p, t, tlab, \
+                      laname+' axis='+str(axis)
 
 class est_calc(object):
     "Test calc functions of larry class"
@@ -167,81 +173,52 @@ class est_calc(object):
         self.assert_(label == p.label, printfail(label, p.label, 'label'))
         self.assert_(noreference(p, self.lar3), 'Reference found')
     
-    def test_movingsum_6(self):
-        "larry.movingsum_6"
-        t = self.tmovingsum 
-        label = self.label
-        p = self.lar.movingsum(2, norm=True)
-        msg = printfail(t, p.x, 'x')  
-        t[np.isnan(t)] = self.nancode
-        p[p.isnan()] = self.nancode             
-        self.assert_((abs(t - p.x) < self.tol).all(), msg)
-        self.assert_(label == p.label, printfail(label, p.label, 'label'))
-        self.assert_(noreference(p, self.lar), 'Reference found')   
-
-    def est_movingsum_6_3(self):
-        "larry.movingsum_6"
-        t = self.tmovingsum
-        label = self.label3
-        p = self.lar3.movingsum(2, norm=True)
-        msg = printfail(t, p.x, 'x')  
-        t[np.isnan(t)] = self.nancode
-        p[p.isnan()] = self.nancode             
-        self.assert_((abs(t - p.x) < self.tol).all(), msg)
-        self.assert_(label == p.label, printfail(label, p.label, 'label'))
-        self.assert_(noreference(p, self.lar3), 'Reference found')  
-        
-    def test_movingsum_6_3(self):
-        "duplicate larry.movingsum_6"
-        t = self.tmovingsum
-        label = self.label3
-        p = self.lar3.movingsum(2, norm=True)
-        self.check_function(t, label, p, self.lar3)
-
     def test_ranking_(self):
         "larry.ranking"  #not in deflarry_test
         t = self.tranking
         label = self.label
-        p = self.lar.ranking(1)
+        with np.errstate(invalid='ignore', divide='ignore'):
+            p = self.lar.ranking(1)
         self.check_function(t, label, p, self.lar)
 
     def test_ranking_3(self):
-        "larry.ranking 3d" 
+        "larry.ranking_3d" 
         t = self.tranking
         label = self.label3
-        p = self.lar3.ranking(2)
+        with np.errstate(invalid='ignore', divide='ignore'):
+            p = self.lar3.ranking(2)
         self.check_function(t, label, p, self.lar3)
 
     def test_lag(self):
-        "larry.ranking 3d" 
+        "larry.lag" 
         t = self.tlag
         label = self.labellag
         p = self.lar.lag(1)
         self.check_function(t, label, p, self.lar)
                 
     def test_lag_3(self):
-        "larry.ranking 3d" 
+        "larry.lag_3d" 
         t = self.tlag
         label = self.label3lag
         p = self.lar3.lag(1)
         self.check_function(t, label, p, self.lar3)
 
     def test_pull(self):
-        "larry.ranking 3d" 
+        "larry.pull" 
         t = self.tpull
         label = self.labelpull
         p = self.lar.pull(1,1)
         self.check_function(t, label, p, self.lar, view='skip')
                 
     def test_pull_3(self):
-        "larry.ranking 3d" 
+        "larry.pull_3d" 
         t = self.tpull
         label = self.label3pull
         p = self.lar3.pull(1,2)
         self.check_function(t, label, p, self.lar3, view='skip')
 
     def test_squeeze(self):
-        "larry.squeeze 3d" 
+        "larry.squeeze" 
         t = self.lar.x
         label = self.lar.label
         x = self.lar.x[None,:]
@@ -250,7 +227,7 @@ class est_calc(object):
         self.check_function(t, label, p, lar, view='skip') #should be nocopy
    
     def test_squeeze_3(self):
-        "larry.squeeze 3d" 
+        "larry.squeeze_3d" 
         t = self.lar3.x
         label = self.lar3.label
         x = self.lar3.x[None,:]
@@ -259,15 +236,15 @@ class est_calc(object):
         self.check_function(t, label, p, lar, view='skip') #should be nocopy
 
     def test_morph_3(self):
-        "larry.morph 3d" 
+        "larry.morph_3d" 
         t = self.tmorph
-        label = self.labelmorph
+        label = self.label
         label[1] = [0,3,2]
         p = self.lar.morph([0,3,2],axis=1)
         self.check_function(t, label, p, self.lar, view='copy')
 
-    def test_morph_3(self):
-        "larry.morph 3d" 
+    def test_morph_3b(self):
+        "larry.morph_3d" 
         t = self.tmorph
         label = self.label3
         label[2] = [0,3,2]
@@ -297,7 +274,7 @@ class Test_calc_la2(est_calc):
         self.labelmedian = self.label
         self.label3median = self.label3
         
-        self.tmovingsum = np.array([[ nan, 4.0, 4.0, 2.0],
+        self.tmove_sum = np.array([[ nan, 4.0, 4.0, 2.0],
                                     [ nan, nan, nan, 2.0],
                                     [ nan, 2.0, 2.0, 2.0]]) 
         
@@ -345,57 +322,58 @@ class est_groups_moving(object):
         "larry.grouprank"  #not in deflarry_test
         t = self.trank1
         label = self.label
-        p = self.lar.group_ranking(self.sectors)
+        with np.errstate(invalid='ignore', divide='ignore'):
+            p = self.lar.group_ranking(self.sectors)
         self.check_function(t, label, p, self.lar)
         
     def test_groupmean(self):
-        "larry.grouprank"  #not in deflarry_test
+        "larry.group_mean"  #not in deflarry_test
         t = self.tmean1
         label = self.label
         p = self.lar.group_mean(self.sectors)
         self.check_function(t, label, p, self.lar)
 
     def test_groupmedian(self):
-        "larry.grouprank"  #not in deflarry_test
+        "larry.group_median"  #not in deflarry_test
         t = self.tmedian1
         label = self.label
         p = self.lar.group_median(self.sectors)
         self.check_function(t, label, p, self.lar)
 
     def test_groupmean3(self):
-        "larry.groupmean 3d"  #not in deflarry_test
+        "larry.group_mean_3d"  #not in deflarry_test
         t = self.tmean3
         label = self.label3
         p = self.lar3.group_mean(self.sectors)
         self.check_function(t, label, p, self.lar3)
 
     def test_groupmedian3(self):
-        "larry.groupmedian 3d"  #not in deflarry_test
+        "larry.group_median_3d"  #not in deflarry_test
         t = self.tmedian3
         label = self.label3
         p = self.lar3.group_median(self.sectors)
         self.check_function(t, label, p, self.lar3)
         
-    def test_movingsum31(self):
-        "larry.movingsum 3d 1"
-        t = self.tmovingsum3
+    def test_move_sum31(self):
+        "larry.move_sum_3d_1"
+        t = self.tmove_sum3
         label = self.label3
-        p = self.lar3.movingsum(2, axis=1, norm=False)
+        p = self.lar3.move_sum(2, axis=1)
         self.check_function(t, label, p, self.lar3) 
         
-    def test_movingsum32(self):
-        "larry.groupmedian 3d 2"
+    def test_move_sum32(self):
+        "larry.move_sum_3d_2"
         #requires numpy 1.4 for nan equality testing 
-        lar3r = self.lar3.movingsum(2, axis=0, norm=True)
-        lar2r = self.lar.movingsum(2, axis=0, norm=True)
+        lar3r = self.lar3.move_sum(2, axis=0)
+        lar2r = self.lar.move_sum(2, axis=0)
         assert_equal(self.label3, lar3r.label)
         assert_equal(lar3r.x[:,:,0], lar2r.x)
         assert_equal(lar3r.x[:,:,1], lar2r.x)
         
-    def test_movingsum33(self):
-        "larry.groupmedian 3d 3"
+    def test_move_sum33(self):
+        "larry.move_sum_3d_3"
         #requires numpy 1.4 for nan equality testing 
-        lar3r = self.lar3.movingsum(2, axis=2, norm=True)
+        lar3r = self.lar3.move_sum(2, axis=2)
         assert_equal(self.label3, lar3r.label)
         assert_(not np.isfinite(lar3r.x[:,:,0]).any())
         assert_equal(lar3r.x[:,:,1], 2*self.lar3.x[:,:,1])
@@ -426,37 +404,36 @@ class Test_group_moving(est_groups_moving):
         self.label = [[0, 1, 2, 3, 4, 5], [0, 1, 2, 3, 4, 5]]
         
         self.trank1 = np.array([[-1.0, 0.0,  nan, nan, -1.0, nan],
-                               [-1.0, 1.0, -1.0, nan,  nan, nan],
-                               [ 0.0,-1.0, -1.0, nan,  0.0, nan],
-                               [ 1.0,-1.0,  1.0, nan,  nan, nan],
-                               [ 1.0, 1.0,  1.0, 0.0,  1.0, nan],
-                               [ 0.0, 0.0,  0.0, 0.0,  nan, nan]])
+                                [-1.0, 1.0, -1.0, nan,  nan, nan],
+                                [ 0.0,-1.0, -1.0, nan,  0.0, nan],
+                                [ 1.0,-1.0,  1.0, nan,  nan, nan],
+                                [ 1.0, 1.0,  1.0, 0.0,  1.0, nan],
+                                [ 0.0, 0.0,  0.0, 0.0,  nan, nan]])
         
         self.tmean1 = np.array([[ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
-                               [ 2.0, 0.5,  1.5, nan,  nan, nan],
-                               [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
-                               [ 2.0, 0.5,  1.5, nan,  nan, nan],
-                               [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
-                               [ 5.0, 5.0,  4.0, 4.0,  nan, nan]])
+                                [ 2.0, 0.5,  1.5, nan,  nan, nan],
+                                [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
+                                [ 2.0, 0.5,  1.5, nan,  nan, nan],
+                                [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
+                                [ 5.0, 5.0,  4.0, 4.0,  nan, nan]])
         
         self.tmean3 = np.dstack([self.tmean1, self.tmean1])
         
         self.tmedian1 = np.array([[ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
-                               [ 2.0, 0.5,  1.5, nan,  nan, nan],
-                               [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
-                               [ 2.0, 0.5,  1.5, nan,  nan, nan],
-                               [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
-                               [ 5.0, 5.0,  4.0, 4.0,  nan, nan]])
+                                  [ 2.0, 0.5,  1.5, nan,  nan, nan],
+                                  [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
+                                  [ 2.0, 0.5,  1.5, nan,  nan, nan],
+                                  [ 2.0, 3.0,  1.5, 0.0,  1.0, nan],
+                                  [ 5.0, 5.0,  4.0, 4.0,  nan, nan]])
         
         self.tmedian3 = np.dstack([self.tmedian1, self.tmedian1])
-        self.tmovingsum1 = np.array([[ nan,   3.,   3.,  nan,   0.,   0.],
-                               [ nan,   2.,   2.,   1.,  nan,  nan],
-                               [ nan,   4.,   2.,   0.,   1.,   1.],
-                               [ nan,   3.,   2.,   2.,  nan,  nan],
-                               [ nan,   8.,   7.,   3.,   2.,   2.],
-                               [ nan,  10.,   9.,   8.,   4.,  nan]])
-        self.tmovingsum3 = np.dstack([self.tmovingsum1, 
-                                      self.tmovingsum1])
+        self.tmove_sum1 = np.array([[ nan,   3.,   3.,  nan,   0.,   0.],
+                                    [ nan,   2.,   2.,   1.,  nan,  nan],
+                                    [ nan,   4.,   2.,   0.,   1.,   1.],
+                                    [ nan,   3.,   2.,   2.,  nan,  nan],
+                                    [ nan,   8.,   7.,   3.,   2.,   2.],
+                                    [ nan,  10.,   9.,   8.,   4.,  nan]])
+        self.tmove_sum3 = np.dstack([self.tmove_sum1, self.tmove_sum1])
 
 # --------------------------------------------------------------------------
 
@@ -560,7 +537,29 @@ def test_conversion():
         os.unlink(filename)
         yield ale, y1, y2, msg % ('csv', str(shape)), False                
         
-                  
+# tofile does not yet have a from file, so it cannot be tested with the
+# roundtrip method above. (Besides it only supports 1d and 2d larrys).
+# Test separately:
+
+def test_tofile():
+    "Test lar.tofile()"
+    
+    # 1d
+    f = StringIO()
+    lar = larry([1, 2], [['r1', 'r2']])
+    lar.tofile(f)
+    actual = f.getvalue()
+    desired = 'r1,1\nr2,2\n'
+    yield assert_equal, actual, desired, "tofile failed on 1d input"
+
+    # 2d
+    f = StringIO()
+    lar = larry([[1, 2], [3, 4]], [['r1', 'r2'], ['c1', 'c2']])
+    lar.tofile(f)
+    actual = f.getvalue()
+    desired = ',c1,c2\nr1,1,2\nr2,3,4\n'
+    yield assert_equal, actual, desired, "tofile failed on 2d input"
+
 # --------------------------------------------------------------------------
 
 # larry dtype test
@@ -620,11 +619,3 @@ def test_comparison():
             desired = comp(1)
             yield ale, actual, desired, msg % (fnc, right)
              
-    
-    
-    
-    
-    
-    
-    
-                                
