@@ -7,9 +7,10 @@ import numpy as np
 nan = np.nan
 from numpy.testing import assert_array_equal
 
-from la import larry
-from la import (union, intersection, panel, stack, cov, align, binaryop, add,
-                subtract, multiply, divide, unique)
+from la import larry, rand
+from la import (union, intersection, panel, stack, cov, align, isaligned,
+                binaryop, add, subtract, multiply, divide, unique, sortby,
+                align_axis, lrange, ones, zeros, empty)
 from la.util.testing import assert_larry_equal as ale
 
 
@@ -37,37 +38,91 @@ class Test_func(unittest.TestCase):
         actual = intersection(1, y1, y2)
         desired = ['d']
         self.assert_(actual == desired, 'intersection axis=1') 
-        
+
+    def test_isaligned_1(self):
+        "isaligned_1"
+        lar1 = larry([[1, 2], [3, 4]], [['r1', 'r2'], ['c1', 'c2']])
+        lar2 = larry([[5, 6], [7, 8]], [['r2', 'r1'], ['c1', 'c2']])
+        a = isaligned(lar1, lar2)
+        self.assert_(~a, "Should return False")
+
+    def test_isaligned_2(self):
+        "isaligned_2"
+        lar1 = larry([[1, 2], [3, 4]], [['r1', 'r2'], ['c1', 'c2']])
+        lar2 = larry([[4, 5], [6, 7]], [['r2', 'r1'], ['c1', 'c2']])
+        a = isaligned(lar1, lar2, axis=0)
+        self.assert_(~a, "Should return False")
+    
+    def test_isaligned_3(self):
+        "isaligned_3"
+        lar1 = larry([[1, 2], [3, 4]], [['r1', 'r2'], ['c1', 'c2']])
+        lar2 = larry([[5, 6], [7, 8]], [['r2', 'r1'], ['c1', 'c2']])
+        a = isaligned(lar1, lar2, axis=1)
+        self.assert_(a, "Should return True")
+
+    def test_isaligned_4(self):
+        "isaligned_4"
+        lar1 = larry([[1, 2], [3, 4]], [['r1', 'r2'], ['c1', 'c2']])
+        lar2 = larry([5, 6], [['r1', 'r2']])
+        a = isaligned(lar1, lar2, axis=0)
+        self.assert_(a, "Should return True")
+    
+    def test_isaligned_5(self):
+        "isaligned_5"
+        lar1 = larry([[1, 2], [3, 4]], [['r1', 'r2'], ['c1', 'c2']])
+        lar2 = larry([5, 6], [['r1', 'r2']])
+        a = isaligned(lar1, lar2)
+        self.assert_(~a, "Should return False")
+
     def test_panel_1(self):
-        "func.panel_1"         
-        original = larry(np.arange(24).reshape(2,3,4))                   
+        "func.panel_1" 
+        x = np.ones((4,3), dtype=np.int).cumsum(0) - 1
+        label = [['r1', 'r2', 'r3', 'r4'], ['c1', 'c2', 'c3']]
+        original = larry(x, label)
+        original = original.insertaxis(0, "name")
         actual = panel(original)
-        x = np.array([[ 0, 12],
-                      [ 4, 16],
-                      [ 8, 20],
-                      [ 1, 13],
-                      [ 5, 17],
-                      [ 9, 21],
-                      [ 2, 14],
-                      [ 6, 18],
-                      [10, 22],
-                      [ 3, 15],
-                      [ 7, 19],
-                      [11, 23]])
-        label = [[(0, 0),
-                  (0, 1),
-                  (0, 2),
-                  (0, 3),
-                  (1, 0),
-                  (1, 1),
-                  (1, 2),
-                  (1, 3),
-                  (2, 0),
-                  (2, 1),
-                  (2, 2),
-                  (2, 3)], [0, 1]]
+        x = np.array([[0,0,0,1,1,1,2,2,2,3,3,3]]).T
+        label = [[('r1', 'c1'),
+                  ('r1', 'c2'),
+                  ('r1', 'c3'),
+                  ('r2', 'c1'),
+                  ('r2', 'c2'),
+                  ('r2', 'c3'),
+                  ('r3', 'c1'),
+                  ('r3', 'c2'),
+                  ('r3', 'c3'),
+                  ('r4', 'c1'),
+                  ('r4', 'c2'),
+                  ('r4', 'c3')], ['name']]
         desired = larry(x, label)         
         ale(actual, desired, msg='panel test #1', original=original) 
+
+    def test_panel_2(self):
+        "func.panel_2" 
+        x = np.ones((4,3)).cumsum(0) - 1
+        label = [['r1', 'r2', 'r3', 'r4'], ['c1', 'c2', 'c3']]
+        original = larry(x, label)
+        original = original.insertaxis(0, "name")
+        y = original.copy()
+        y.label[0] = ["two"]
+        original = original.merge(y)
+        actual = panel(original)
+        x = np.array([[0,0,0,1,1,1,2,2,2,3,3,3]], dtype=np.float).T
+        x = np.hstack((x,x))
+        label = [[('r1', 'c1'),
+                  ('r1', 'c2'),
+                  ('r1', 'c3'),
+                  ('r2', 'c1'),
+                  ('r2', 'c2'),
+                  ('r2', 'c3'),
+                  ('r3', 'c1'),
+                  ('r3', 'c2'),
+                  ('r3', 'c3'),
+                  ('r4', 'c1'),
+                  ('r4', 'c2'),
+                  ('r4', 'c3')], ['name', 'two']]
+        desired = larry(x, label)         
+        ale(actual, desired, msg='panel test #2', original=original) 
         
     def test_stack_1(self):
         "func.stack_1"           
@@ -336,6 +391,16 @@ class Test_align_1d(unittest.TestCase):
         ale(a1, d1, msg % 'left', original=y1)
         ale(a2, d2, msg % 'right', original=y2)
 
+    def test_1d21(self):
+        "align 1d test #21"
+        y1 = larry([1, 2, 3])
+        y2 = larry([1, 2, 3, 4])
+        a1, a2 = align(y1, y2, join='skip')
+        d1, d2 = y1.copy(), y2.copy()
+        msg = "align 1d fail on %s larry"
+        ale(a1, d1, msg % 'left', original=y1)
+        ale(a2, d2, msg % 'right', original=y2)
+
 class Test_align_2d(unittest.TestCase):
     "Test 2d alignment of larrys"   
 
@@ -417,7 +482,254 @@ class Test_align_2d(unittest.TestCase):
         msg = "align 2d fail on %s larry"
         ale(a1, d1, msg % 'left', original=y1)
         ale(a2, d2, msg % 'right', original=y2)
-        
+    
+    def test_2d9(self):
+        "align 2d test #9"
+        y1 = larry([[1, 2],    [3, 4]])
+        y2 = larry([[1, 2, 5], [3, 4, 6]])
+        a1, a2 = align(y1, y2, 'skip')
+        d1, d2 = y1.copy(), y2.copy()
+        msg = "align 2d fail on %s larry"
+        ale(a1, d1, msg % 'left', original=y1)
+        ale(a2, d2, msg % 'right', original=y2)            
+
+    def test_2d10(self):
+        "align 2d test #10"
+        y1 = larry([[1, 2], [3, 4], [7, 8]])
+        y2 = larry([[1, 2, 5], [3, 4, 6]])
+        a1, a2 = align(y1, y2, ['inner', 'skip'])
+        d1 = larry([[1, 2], [3, 4]])
+        d2 = larry([[1, 2, 5], [3, 4, 6]])
+        msg = "align 2d fail on %s larry"
+        ale(a1, d1, msg % 'left', original=y1)
+        ale(a2, d2, msg % 'right', original=y2)            
+
+    def test_2d11(self):
+        "align 2d test #11"
+        y1 = larry([[0.1, 0.2], [0.3, 0.4], [0.7, 0.8]])
+        y2 = larry([[0.1, 0.2, 0.5], [0.3, 0.4, 0.6]])
+        a1, a2 = align(y1, y2, ['skip', 'outer'])
+        d1 = larry([[0.1, 0.2, np.nan], [0.3, 0.4, np.nan],
+                    [0.7, 0.8, np.nan]])
+        d2 = larry([[0.1, 0.2, 0.5],    [0.3, 0.4, 0.6]])
+        msg = "align 2d fail on %s larry"
+        ale(a1, d1, msg % 'left', original=y1)
+        ale(a2, d2, msg % 'right', original=y2)            
+
+class Test_align_axis(unittest.TestCase):
+    "Test align_axis on larrys"
+
+    def test_align_axis_1(self):
+        y1 = larry([[0.1, 0.2], [0.3, 0.4], [0.7, 0.8]])
+        y2 = larry([[0.1, 0.2, 0.5], [0.3, 0.4, 0.6]])
+        a1, a2 = align_axis([y1, y2], axis=1, join='outer')
+        d1 = larry([[0.1, 0.2, np.nan], [0.3, 0.4, np.nan],
+                    [0.7, 0.8, np.nan]])
+        d2 = larry([[0.1, 0.2, 0.5],    [0.3, 0.4, 0.6]])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % 'left', original=y1)
+        ale(a2, d2, msg % 'right', original=y2) 
+    
+    def test_align_axis_2(self):
+        "align 2d test #10"
+        y1 = larry([[1, 2], [3, 4], [7, 8]])
+        y2 = larry([[1, 2, 5], [3, 4, 6]])
+        a1, a2 = align_axis([y1, y2], axis=0, join='inner')
+        d1 = larry([[1, 2], [3, 4]])
+        d2 = larry([[1, 2, 5], [3, 4, 6]])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % 'left', original=y1)
+        ale(a2, d2, msg % 'right', original=y2)
+
+    def test_align_axis_3(self):
+        y1 = larry([1.0, 2.0, 3.0, 4.0], [[1, 2, 3, 4]])
+        y2 = larry([5.0, 6.0], [[2, 3]])
+        y3 = larry([7.0, 8.0, 9.0], [[2, 3, 5]])
+        a1, a2, a3 = align_axis([y1, y2, y3])
+        dlab = [[2, 3]]
+        d1 = larry([2.0, 3.0], dlab)
+        d2 = larry([5.0, 6.0], dlab)
+        d3 = larry([7.0, 8.0], dlab)
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+
+    def test_align_axis_4(self):
+        y1 = larry([1.0, 2.0, 3.0, 4.0], [[1, 2, 3, 4]])
+        y2 = larry([5.0, 6.0], [[2, 3]])
+        y3 = larry([7.0, 8.0, 9.0], [[2, 3, 5]])
+        a1, a2, a3 = align_axis([y1, y2, y3], join='outer')
+        dlab = [[1, 2, 3, 4, 5]]
+        d1 = larry([1.0, 2.0, 3.0, 4.0, nan], dlab)
+        d2 = larry([nan, 5.0, 6.0, nan, nan], dlab)
+        d3 = larry([nan, 7.0, 8.0, nan, 9.0], dlab)
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+
+    def test_align_axis_5(self):
+        y1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        y2 = larry([['x'], ['y'], ['z']], [['a', 'b', 'cc'], [1]])
+        y3 = larry([50, 51, 52], [['aa', 'b', 'c']])
+        a1, a2, a3 = align_axis([y1, y2, y3], axis=0, join='inner')
+        d1 = larry([[3.0, 4.0]], [['b'], [1, 2]])
+        d2 = larry([['y']], [['b'], [1]])
+        d3 = larry([51], [['b']])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+       
+    def test_align_axis_6(self):
+        y1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        y2 = larry([['x'], ['y'], ['z']], [['a', 'b', 'cc'], [1]])
+        y3 = larry([50, 51, 52], [['aa', 'b', 'c']])
+        a1, a2, a3 = align_axis([y1, y2, y3], axis=0, join='outer')
+        d1 = larry([[1.0, 2.0],
+                    [nan, nan],
+                    [3.0, 4.0],
+                    [5.0, 6.0],
+                    [nan, nan]], 
+                   label = [['a', 'aa', 'b', 'c', 'cc'], [1, 2]])
+        d2 = larry([['x'], [''], ['y'], [''], ['z']], 
+                   [['a', 'aa', 'b', 'c', 'cc'], [1]])
+        d3 = larry([nan, 50.0, 51.0, 52.0, nan], [['a', 'aa', 'b', 'c', 'cc']])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+
+    def test_align_axis_7(self):
+        y1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        y2 = larry([['x'], ['y'], ['z']], [['a', 'b', 'cc'], [1]])
+        y3 = larry([50, 51, 52], [['aa', 'b', 'c']])
+        a1, a2, a3 = align_axis([y1, y2, y3], axis=0, join='left')
+        d1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        d2 = larry([['x'], ['y'], ['']], 
+                   [['a', 'b', 'c'], [1]])
+        d3 = larry([nan, 51.0, 52.0], [['a', 'b', 'c']])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+
+    def test_align_axis_8(self):
+        y1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        y2 = larry([['x'], ['y'], ['z']], [['a', 'b', 'cc'], [1]])
+        y3 = larry([50, 51, 52], [['aa', 'b', 'c']])
+        a3, a2, a1 = align_axis([y3, y2, y1], axis=0, join='right')
+        d1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        d2 = larry([['x'], ['y'], ['']], 
+                   [['a', 'b', 'c'], [1]])
+        d3 = larry([nan, 51.0, 52.0], [['a', 'b', 'c']])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+
+    def test_align_axis_9(self):
+        y1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        y1 = y1.T
+        y2 = larry([['x'], ['y'], ['z']], [['a', 'b', 'cc'], [1]])
+        y3 = larry([50, 51, 52], [['aa', 'b', 'c']])
+        a1, a2, a3 = align_axis([y1, y2, y3], axis=[1, 0, 0], join='left')
+        d1 = larry([[1.0, 2.0],
+                    [3.0, 4.0],
+                    [5.0, 6.0]], [['a', 'b', 'c'], [1, 2]])
+        d1 = d1.T
+        d2 = larry([['x'], ['y'], ['']], 
+                   [['a', 'b', 'c'], [1]])
+        d3 = larry([nan, 51.0, 52.0], [['a', 'b', 'c']])
+        msg = "align_axis fail on %s larry"
+        ale(a1, d1, msg % '1st', original=y1)
+        ale(a2, d2, msg % '2nd', original=y2)
+        ale(a3, d3, msg % '3rd', original=y3)
+
+class Test_quick_inst(unittest.TestCase):
+    "Test quick larry-creation functions."
+
+    def test_lrange_1(self):
+        a = lrange(5)
+        d = larry([0, 1, 2, 3, 4])
+        ale(a, d, "lrange failed.")
+
+    def test_lrange_2(self):
+        a = lrange(label=[['a', 'b', 'c', 'd']])
+        d = larry([0, 1, 2, 3], [['a', 'b', 'c', 'd']])
+        ale(a, d, "lrange failed.")
+
+    def test_lrange_3(self):
+        a = lrange((2, 2), dtype='f8')
+        d = larry(np.array([0, 1, 2, 3], dtype='f8').reshape(2,2))
+        ale(a, d, "lrange failed.")
+
+    def test_lrange_4(self):
+        a = lrange(label=[['a', 'b'], ['c', 'd']])
+        d = larry([[0, 1], [2, 3]], [['a', 'b'], ['c', 'd']])
+        ale(a, d, "lrange failed.")
+
+    def test_lrange_5(self):
+        self.failUnlessRaises(ValueError, lrange, (2,), ['a', 'b', 'c'])
+
+    def test_empty_1(self):
+        self.failUnlessRaises(ValueError, empty, (2,), ['a', 'b', 'c'])
+
+    def test_ones_1(self):
+        a = ones(5)
+        d = larry([1., 1., 1., 1., 1.])
+        ale(a, d, "ones failed.")
+
+    def test_ones_2(self):
+        a = ones(label=[['a', 'b', 'c', 'd']])
+        d = larry([1., 1., 1., 1.], [['a', 'b', 'c', 'd']])
+        ale(a, d, "ones failed.")
+
+    def test_ones_3(self):
+        a = ones((2, 2), dtype='i8')
+        d = larry(np.array([1., 1., 1., 1.], dtype='i8').reshape(2,2))
+        ale(a, d, "ones failed.")
+
+    def test_ones_4(self):
+        a = ones(label=[['a', 'b'], ['c', 'd']])
+        d = larry([[1., 1.], [1., 1.]], [['a', 'b'], ['c', 'd']])
+        ale(a, d, "ones failed.")
+
+    def test_zeros_1(self):
+        a = zeros(5)
+        d = larry([0., 0., 0., 0., 0.])
+        ale(a, d, "zeros failed.")
+
+    def test_zeros_2(self):
+        a = zeros(label=[['a', 'b', 'c', 'd']])
+        d = larry([0., 0., 0., 0.], [['a', 'b', 'c', 'd']])
+        ale(a, d, "zeros failed.")
+
+    def test_zeros_3(self):
+        a = zeros((2, 2), dtype='i8')
+        d = larry(np.array([0., 0., 0., 0.], dtype='i8').reshape(2,2))
+        ale(a, d, "zeros failed.")
+
+    def test_zeros_4(self):
+        a = zeros(label=[['a', 'b'], ['c', 'd']])
+        d = larry([[0., 0.], [0., 0.]], [['a', 'b'], ['c', 'd']])
+        ale(a, d, "zeros failed.")
+
 class Test_binaryop(unittest.TestCase):
     "Test la.binaryop()"   
 
@@ -917,3 +1229,87 @@ class Test_divide(unittest.TestCase):
         ale(actual, desired, msg, original=y1)
         ale(actual, desired, msg, original=y2)
                     
+class Test_sortby(unittest.TestCase):
+    "Test la.sortby()"
+    
+    def setUp(self):
+        label = [['a','b'], ['c','d','e']]
+        x = np.array([[1, 2, 3],
+                      [3, 1, 2]])
+        self.lar = larry(x,label)
+        
+    def test_sortby_1(self):
+        "sortby test #1"
+        theory = self.lar[:,[1, 2, 0]]
+        practice = sortby(self.lar, 'b', 0)
+        msg = "Sorting by element in axis 0 failed"
+        ale(theory, practice, msg=msg)
+    
+    def test_sortby_2(self):
+        "sortby test #2"
+        theory = self.lar[[1, 0],:]
+        practice = sortby(self.lar, 'e', 1)
+        msg="Sorting by element in axis 1 failed"
+        ale(theory, practice, msg=msg)
+
+    def test_sortby_3(self):
+        "sortby test #3"
+        theory = self.lar[:,[1, 2, 0]]
+        practice = sortby(self.lar, 'b', -2)
+        msg = "Sorting by element in axis -2 failed"
+        ale(theory, practice, msg=msg)
+    
+    def test_sortby_4(self):
+        "sortby test #4"
+        theory = self.lar[[1, 0],:]
+        practice = sortby(self.lar, 'e', -1)
+        msg="Sorting by element in axis -1 failed"
+        ale(theory, practice, msg=msg)
+
+    def test_sortby_5(self):
+        "sortby test #5"
+        theory = self.lar[:,[0, 2, 1]]
+        practice = sortby(self.lar, 'b', 0, reverse=True)
+        msg = "Reverse sorting by element in axis 0 failed"
+        ale(theory, practice, msg=msg)
+    
+    def test_sortby_6(self):
+        "sortby test #6"
+        theory = self.lar
+        practice = sortby(self.lar, 'e', 1, reverse=True)
+        msg="Reverse sorting by element in axis 1 failed"
+        ale(theory, practice, msg=msg)
+
+    def test_sortby_7(self):
+        "sortby test #7"
+        theory = larry([[]])
+        practice = sortby(theory, 0, 0)
+        msg = "Sorting empty larry failed"
+        ale(theory, practice, msg=msg)
+        
+    def test_sortby_8(self): 
+        "sortby test #8"
+        self.assertRaises(ValueError, sortby, self.lar, 'b', 2)   
+    
+    def test_sortby_9(self):
+        "sortby test #9"
+        self.assertRaises(ValueError, sortby, self.lar, 'b', -3)
+        
+    def test_sortby_10(self):
+        "sortby test #10"
+        lar = self.lar[0]
+        self.assertRaises(ValueError, sortby, lar, 'd', 0) 
+    
+    def test_sortby_11(self):
+        "sortby test #11"
+        lar = rand(0,2)
+        self.assertRaises(IndexError, sortby, lar, 0, 0)
+        
+    def test_sortby_12(self):
+        "sortby test #12"
+        lar = rand(0,2)
+        theory = lar.copy()
+        practice = sortby(lar, 0, 1)
+        msg="Sorting empty larry failed"
+        ale(theory, practice, msg=msg)
+        
