@@ -2,33 +2,10 @@
 
 import random
 import string
-from itertools import izip
 
 import numpy as np
+from la.flabel import list2index
 
-try:
-    # The c version is faster...
-    from la.util.clistmap import listmap
-except ImportError:
-    # ...but perhaps it did not compile when you built the la package? So
-    # we'll use the python version. If you are unsure which version you are
-    # using, the doc string will tell you.
-    def listmap(list1, list2):
-        """
-        list of indices idx such that [list1[i] for i in idx] is list2.
-        
-        This function is equivalent to idx = map(list1.index, list2) except
-        that it is O(n) instead of O(n^2).
-        
-        All elements in list2 must be in list1 
-        
-        NOTE: This is the slower python version of the function; there is a 
-        faster C version that setup.py will automatically try to compile at
-        build (setup.py) time.   
-        """
-        list1map = dict(izip(list1, xrange(len(list1))))
-        idx = [list1map[i] for i in list2]
-        return idx
         
 C = string.letters + string.digits
 def randstring(n):
@@ -39,30 +16,6 @@ def randstring(n):
         s.append(C[random.randint(0, nc)])
     return ''.join(s) 
     
-def flattenlabel(label, order='C'):
-    """
-    Flatten label in row-major order 'C' (default) or column-major order 'F'.
-    
-    Code taken (but modified) from http://code.activestate.com/recipes/496807
-    
-    """
-    if order not in ('C', 'F'):
-        raise ValueError, "order must be 'C' or 'F'"
-    label = list(label)
-    if order == 'C':
-        label = label[::-1]
-    idx = [[]]
-    for x in label:
-        t = []
-        for y in x:
-            for i in idx:
-                t.append(i+[y])
-        idx = t
-    if order == 'C':
-        idx = [i[::-1] for i in idx]
-    idx = [tuple(i) for i in idx]     
-    return [idx]
-    
 def isint(x):
     """Returns True if input is an integer; False otherwise.
     
@@ -203,13 +156,7 @@ def isscalar(x):
     
 def isstring(s):
     "Return True if input is a str or np.string_."
-    return issubclass(type(s), str)      
-    
-def list2index(L):
-    "Convert a list to a unique list and the corresponding indices."
-    uL = sorted(set(L))
-    idx = dict((y, x) for x, y in enumerate(uL))
-    return [idx[x] for x in L], uL  
+    return issubclass(type(s), str)
 
 def fromlists(xs, labels):
     """
