@@ -1,6 +1,6 @@
 "Information about your particular installation of the la package."
 
-from la.util.prettytable import indent
+from la.external.prettytable import indent
     
 def info():
     "la package information such as version number and HDF5 availability."
@@ -20,13 +20,25 @@ def info():
     try:
         from la import IO
         io = "Available"
-    except IMportError:
-        io = "Not available"    
+        try:
+            import h5py
+            version = h5py.version.version
+            io = io + " (h5py %s)" % str(version)
+        except:
+            pass
+    except ImportError:
+        io = "Not available"
+
+    # Others
+    import numpy as np
+    import bottleneck as bn
     
     # Make and print report
     table = []
-    table.append(['la version', la.__version__])
+    table.append(['la', la.__version__])
     table.append(['la file', la.__file__])
+    table.append(['NumPy', np.__version__])
+    table.append(['Bottleneck', bn.__version__])
     table.append(['HDF5 archiving', io])  
     table.append(['listmap', listmap])
     table.append(['listmap_fill', listmap_fill])         
